from datetime import timedelta


# Set to default value by using timedelta of 0
TIMEOUT_DEFAULT = timedelta(0)
TIMEOUT_MIN = timedelta(minutes=1)
TIMEOUT_MAX = timedelta(days=30)
TIMEOUT_DEFAULT_UNIT = 'minutes'
TIMEOUT_ALLOWED_UNITS = ('days', 'hours', 'minutes')

_ENFORCEMENTS = [
    ("MASTER_PASSWORD_MINIMUM_LENGTH", 10, "LONG"),
    ("MASTER_PASSWORD_MINIMUM_SPECIAL", 11, "LONG"),
    ("MASTER_PASSWORD_MINIMUM_UPPER", 12, "LONG"),
    ("MASTER_PASSWORD_MINIMUM_LOWER", 13, "LONG"),
    ("MASTER_PASSWORD_MINIMUM_DIGITS", 14, "LONG"),
    ("MASTER_PASSWORD_RESTRICT_DAYS_BEFORE_REUSE", 16, "LONG"),
    ("REQUIRE_TWO_FACTOR", 20, "BOOLEAN"),
    ("MASTER_PASSWORD_MAXIMUM_DAYS_BEFORE_CHANGE", 22, "LONG"),
    ("MASTER_PASSWORD_EXPIRED_AS_OF", 23, "LONG"),
    ("MINIMUM_PBKDF2_ITERATIONS", 55, "LONG"),
    ("MAX_SESSION_LOGIN_TIME", 24, "LONG"),
    ("RESTRICT_PERSISTENT_LOGIN", 25, "BOOLEAN"),
    ("RESTRICT_SHARING_ALL", 30, "BOOLEAN"),
    ("RESTRICT_SHARING_ENTERPRISE", 31, "BOOLEAN"),
    ("RESTRICT_EXPORT", 32, "BOOLEAN"),
    ("RESTRICT_FILE_UPLOAD", 33, "BOOLEAN"),
    ("REQUIRE_ACCOUNT_SHARE", 34, "ACCOUNT_SHARE"),
    ("RESTRICT_SHARING_INCOMING_ALL", 36, "BOOLEAN"),
    ("RESTRICT_SHARING_INCOMING_ENTERPRISE", 37, "BOOLEAN"),
    ("RESTIRCT_SHARING_RECORD_AND_FOLDER", 120, "BOOLEAN"),
    ("RESTRICT_SHARING_RECORD_WITH_ATTACHMENTS", 121, "BOOLEAN"),
    ("RESTRICT_IP_ADDRESSES", 40, "IP_WHITELIST"),
    ("REQUIRE_DEVICE_APPROVAL", 41, "BOOLEAN"),
    ("REQUIRE_ACCOUNT_RECOVERY_APPROVAL", 42, "BOOLEAN"),
    ("RESTRICT_VAULT_IP_ADDRESSES", 43, "IP_WHITELIST"),
    ("TIP_ZONE_RESTRICT_ALLOWED_IP_RANGES", 44, "IP_WHITELIST"),
    ("AUTOMATIC_BACKUP_EVERY_X_DAYS", 45, "LONG"),
    ("RESTRICT_OFFLINE_ACCESS", 46, "BOOLEAN"),
    ("SEND_INVITE_AT_REGISTRATION", 47, "BOOLEAN"),
    ("RESTRICT_EMAIL_CHANGE", 48, "BOOLEAN"),
    ("RESTRICT_IOS_FINGERPRINT", 49, "BOOLEAN"),
    ("RESTRICT_MAC_FINGERPRINT", 50, "BOOLEAN"),
    ("RESTRICT_ANDROID_FINGERPRINT", 51, "BOOLEAN"),
    ("RESTRICT_WINDOWS_FINGERPRINT", 83, "BOOLEAN"),
    ("LOGOUT_TIMER_WEB", 52, "LONG"),
    ("LOGOUT_TIMER_MOBILE", 53, "LONG"),
    ("LOGOUT_TIMER_DESKTOP", 54, "LONG"),
    ("RESTRICT_WEB_VAULT_ACCESS", 60, "BOOLEAN"),
    ("RESTRICT_EXTENSIONS_ACCESS", 61, "BOOLEAN"),
    ("RESTRICT_MOBILE_ACCESS", 62, " BOOLEAN"),
    ("RESTRICT_DESKTOP_ACCESS", 63, "BOOLEAN"),
    ("RESTRICT_MOBILE_IOS_ACCESS", 64, "BOOLEAN"),
    ("RESTRICT_MOBILE_ANDROID_ACCESS", 65, "BOOLEAN"),
    ("RESTRICT_MOBILE_WINDOWS_PHONE_ACCESS", 66, "BOOLEAN"),
    ("RESTRICT_DESKTOP_WIN_ACCESS", 67, "BOOLEAN"),
    ("RESTRICT_DESKTOP_MAC_ACCESS", 68, "BOOLEAN"),
    ("RESTRICT_CHAT_DESKTOP_ACCESS", 84, "BOOLEAN"),
    ("RESTRICT_CHAT_MOBILE_ACCESS", 85, "BOOLEAN"),
    ("RESTRICT_COMMANDER_ACCESS", 88, "BOOLEAN"),
    ("RESTRICT_TWO_FACTOR_CHANNEL_TEXT", 70, "BOOLEAN"),
    ("RESTRICT_TWO_FACTOR_CHANNEL_GOOGLE", 71, "BOOLEAN"),
    ("RESTRICT_TWO_FACTOR_CHANNEL_DNA", 72, "BOOLEAN"),
    ("RESTRICT_TWO_FACTOR_CHANNEL_DUO", 73, "BOOLEAN"),
    ("RESTRICT_TWO_FACTOR_CHANNEL_RSA", 74, "BOOLEAN"),
    ("TWO_FACTOR_DURATION_WEB", 80, "TWO_FACTOR_DURATION"),
    ("TWO_FACTOR_DURATION_MOBILE", 81, "TWO_FACTOR_DURATION"),
    ("TWO_FACTOR_DURATION_DESKTOP", 82, "TWO_FACTOR_DURATION"),
    ("RESTRICT_TWO_FACTOR_CHANNEL_SECURITY_KEYS", 86, "BOOLEAN"),
    ("TWO_FACTOR_BY_IP", 87, "JSONARRAY"),
    ("RESTRICT_DOMAIN_ACCESS", 90, "STRING"),
    ("RESTRICT_DOMAIN_CREATE", 91, "STRING"),
    ("RESTRICT_HOVER_LOCKS", 92, "BOOLEAN"),
    ("RESTRICT_PROMPT_TO_LOGIN", 93, "BOOLEAN"),
    ("RESTRICT_PROMPT_TO_FILL", 94, "BOOLEAN"),
    ("RESTRICT_AUTO_SUBMIT", 95, "BOOLEAN"),
    ("RESTRICT_PROMPT_TO_SAVE", 96, "BOOLEAN"),
    ("RESTRICT_PROMPT_TO_CHANGE", 97, "BOOLEAN"),
    ("RESTRICT_AUTO_FILL", 98, "BOOLEAN"),
    ("RESTRICT_CREATE_FOLDER", 100, "BOOLEAN"),
    ("RESTRICT_CREATE_IDENTITY_PAYMENT_RECORDS", 102, "BOOLEAN"),
    ("MASK_CUSTOM_FIELDS", 103, "BOOLEAN"),
    ("MASK_NOTES", 104, "BOOLEAN"),
    ("MASK_PASSWORDS_WHILE_EDITING", 105, "BOOLEAN"),
    ("GENERATED_PASSWORD_COMPLEXITY", 106, "STRING"),
    ("GENERATED_SECURITY_QUESTION_COMPLEXITY", 109, "STRING"),
    ("RESTRICT_IMPORT", 111, "BOOLEAN"),
    ("DAYS_BEFORE_DELETED_RECORDS_CLEARED_PERM", 107, "LONG"),
    ("DAYS_BEFORE_DELETED_RECORDS_AUTO_CLEARED", 108, "LONG"),
    ("ALLOW_ALTERNATE_PASSWORDS", 110, "BOOLEAN"),
    ("DISABLE_SETUP_TOUR", 140, "BOOLEAN"),
    ("RESTRICT_PERSONAL_LICENSE", 141, "BOOLEAN"),
    ("DISABLE_ONBOARDING", 142, "BOOLEAN"),
    ("DISALLOW_V2_CLIENTS", 143, "BOOLEAN"),
    ("RESTRICT_IP_AUTOAPPROVAL", 144, "BOOLEAN"),
    ("SEND_BREACH_WATCH_EVENTS", 200, "BOOLEAN"),
    ("RESTRICT_BREACH_WATCH", 201, "BOOLEAN"),
    ("RESEND_ENTERPRISE_INVITE_IN_X_DAYS", 202, "LONG"),
    ("MASTER_PASSWORD_REENTRY", 203, "JSON"),
    ("RESTRICT_ACCOUNT_RECOVERY", 204, "BOOLEAN"),
    ("KEEPER_FILL_HOVER_LOCKS", 205, "TERNARY_DEN"),
    ("KEEPER_FILL_AUTO_FILL", 206, "TERNARY_DEN"),
    ("KEEPER_FILL_AUTO_SUBMIT", 207, "TERNARY_DEN"),
    ("KEEPER_FILL_MATCH_ON_SUBDOMAIN", 208, "TERNARY_EDN"),
    ("RESTRICT_PROMPT_TO_DISABLE", 209, "BOOLEAN"),
    ("RESTRICT_HTTP_FILL_WARNING", 210, "BOOLEAN"),
    ("RESTRICT_RECORD_TYPES", 211, "RECORD_TYPES"),
    ("ALLOW_SECRETS_MANAGER", 212, "BOOLEAN")
]

ENFORCEMENTS = {}
for e in _ENFORCEMENTS:
    ENFORCEMENTS[e[0].lower()] = e[2].lower()
